==> libzypp-docs-17.37.17-1-x86_64.pkg.tar.zst: usr/share/doc/libzypp/html/autodoc/html/group__g__RAII.js <==
var group__g__RAII =
[
    [ "zypp::SignalSaver", "classzypp_1_1SignalSaver.html", [
      [ "SignalSaver", "classzypp_1_1SignalSaver.html#a1db507c6f864572da91b2adf5a8040be", null ],
      [ "~SignalSaver", "classzypp_1_1SignalSaver.html#ac44fa6a307eb31209ab258076a55f272", null ],
      [ "_signum", "classzypp_1_1SignalSaver.html#ae761110ece01a85a39d3b6df2de86b46", null ],
      [ "_orighandler", "classzypp_1_1SignalSaver.html#a0e38755c373ca92d13c050ad66cbb534", null ]
    ] ],
    [ "zypp::SigprocmaskSaver", "classzypp_1_1SigprocmaskSaver.html", [
      [ "SigprocmaskSaver", "classzypp_1_1SigprocmaskSaver.html#a22a279aaa50c96453243d4862c164e2e", null ],
      [ "~SigprocmaskSaver", "classzypp_1_1SigprocmaskSaver.html#a07093d7dc30f68e89101c65e6f7dbe02", null ],
      [ "block", "classzypp_1_1SigprocmaskSaver.html#a10d8413dfa195511c9f9dd9dc7ee946e", null ],
      [ "unblock", "classzypp_1_1SigprocmaskSaver.html#a25d6a09e3ac9d33702f681a57d248ea0", null ],
      [ "pending", "classzypp_1_1SigprocmaskSaver.html#a22f4b3e18f176688db261ec7f731bae7", null ],
      [ "suspend", "classzypp_1_1SigprocmaskSaver.html#a69354e491002ab17fb039a4df255dd75", null ],
      [ "_origmask", "classzypp_1_1SigprocmaskSaver.html#a760a465482b6ec33862f6074e2a60b71", null ]
    ] ],
    [ "zypp::solver::detail::ScopedAutoTestCaseWriter", "structzypp_1_1solver_1_1detail_1_1ScopedAutoTestCaseWriter.html", [
      [ "ScopedAutoTestCaseWriter", "structzypp_1_1solver_1_1detail_1_1ScopedAutoTestCaseWriter.html#ac59a04e2f35fa665da0ed8a1542aa1ca", null ],
      [ "~ScopedAutoTestCaseWriter", "structzypp_1_1solver_1_1detail_1_1ScopedAutoTestCaseWriter.html#a43acc428e3aee64652b46645fc5d5fcb", null ],
      [ "_resolver", "structzypp_1_1solver_1_1detail_1_1ScopedAutoTestCaseWriter.html#a5c33d3177e444e03a5ff05932b161f17", null ],
      [ "dumpPool", "structzypp_1_1solver_1_1detail_1_1ScopedAutoTestCaseWriter.html#a73f5ab04e5a8518d143b5d53e715256b", null ]
    ] ],
    [ "zypp::target::rpm::HeaderEntryGetter", "structzypp_1_1target_1_1rpm_1_1HeaderEntryGetter.html", [
      [ "HeaderEntryGetter", "structzypp_1_1target_1_1rpm_1_1HeaderEntryGetter.html#ada2db8997424871270e374ef4a71d023", null ],
      [ "HeaderEntryGetter", "structzypp_1_1target_1_1rpm_1_1HeaderEntryGetter.html#a7d8b9d3e5f912d7b853f1d6c54c150cb", null ],
      [ "HeaderEntryGetter", "structzypp_1_1target_1_1rpm_1_1HeaderEntryGetter.html#aa7c40ecf4f04c6ea5a96345a09b13bcd", null ],
      [ "~HeaderEntryGetter", "structzypp_1_1target_1_1rpm_1_1HeaderEntryGetter.html#a455def84d1e7875bdd9133e66516d0f3", null ],
      [ "operator=", "structzypp_1_1target_1_1rpm_1_1HeaderEntryGetter.html#a3365d8f6567c687ec9fd90c884983a3d", null ],
      [ "operator=", "structzypp_1_1target_1_1rpm_1_1HeaderEntryGetter.html#a5dca6b2e7a2d5c8b4b6975e409b5a6f7", null ],
      [ "type", "structzypp_1_1target_1_1rpm_1_1HeaderEntryGetter.html#af1d33c1117cc9eced76eb98863a5cdb2", null ],
      [ "cnt", "structzypp_1_1target_1_1rpm_1_1HeaderEntryGetter.html#ab51ca1e12266541d578cd4871d3c4d92", null ],
      [ "val", "structzypp_1_1target_1_1rpm_1_1HeaderEntryGetter.html#a785e862b350971e8095e8b41872ce453", null ],
      [ "_rpmtd", "structzypp_1_1target_1_1rpm_1_1HeaderEntryGetter.html#a27f0ecfccb9861c4ec5952b350a3ec7f", null ]
    ] ],
    [ "zypp::DtorReset", "classzypp_1_1DtorReset.html", [
      [ "Impl", "structzypp_1_1DtorReset_1_1Impl.html", [
        [ "Impl", "structzypp_1_1DtorReset_1_1Impl.html#a4712f33294c3d5ed9b7e705704b6defd", null ],
        [ "~Impl", "structzypp_1_1DtorReset_1_1Impl.html#a8c49eadfb70407829676978c010023bf", null ],
        [ "_var", "structzypp_1_1DtorReset_1_1Impl.html#a04f625138e68e7933302c3db8f901083", null ],
        [ "_val", "structzypp_1_1DtorReset_1_1Impl.html#adf7c174da71cc9b154e444f215eef825", null ]
      ] ],
      [ "DtorReset", "classzypp_1_1DtorReset.html#aa43af29f4262ca1b5ea3531ee575f523", null ],
      [ "DtorReset", "classzypp_1_1DtorReset.html#a106c8b56f67255234b046f14c1f3f5a7", null ],
      [ "DtorReset", "classzypp_1_1DtorReset.html#a0a719ff20b63f83e975ef848b4741dca", null ],
      [ "_pimpl", "classzypp_1_1DtorReset.html#a11c072d16bc47aa7872c323e275d6fa5", null ]
    ] ],
    [ "zypp::str::SafeBuf", "structzypp_1_1str_1_1SafeBuf.html", [
      [ "SafeBuf", "structzypp_1_1str_1_1SafeBuf.html#a586dabf29ac7a72b5f951d8c9144dd61", null ],
      [ "~SafeBuf", "structzypp_1_1str_1_1SafeBuf.html#a72cdcac6091c826bdc14995bc9c90e9c", null ],
      [ "asString", "structzypp_1_1str_1_1SafeBuf.html#a4e5b21b6f2ea1fc368dae67c0f3fe164", null ],
      [ "_buf", "structzypp_1_1str_1_1SafeBuf.html#a320bba0ea756554acbec4891d1342e05", null ]
    ] ],
    [ "zypp::env::ScopedSet", "structzypp_1_1env_1_1ScopedSet.html", [
      [ "ScopedSet", "structzypp_1_1env_1_1ScopedSet.html#a02f4fc4e5a9e16cfc227d819c790ffa1", null ],
      [ "ScopedSet", "structzypp_1_1env_1_1ScopedSet.html#aca93ed9695126bf8ec93dbba4af449d3", null ],
      [ "ScopedSet", "structzypp_1_1env_1_1ScopedSet.html#a37f3becbcd499d8988501741a7a6964d", null ],
      [ "ScopedSet", "structzypp_1_1env_1_1ScopedSet.html#a2684ce98aea79484fa3f7b27a09e2ace", null ],
      [ "~ScopedSet", "structzypp_1_1env_1_1ScopedSet.html#ae08c521454ba1482a56f77c7433e1c99", null ],
      [ "operator=", "structzypp_1_1env_1_1ScopedSet.html#a0b47063a69f477bb0ca7200d19fc5b6c", null ],
      [ "operator=", "structzypp_1_1env_1_1ScopedSet.html#a87bdaac67eb7466a08e049964e00ad0e", null ],
      [ "setval", "structzypp_1_1env_1_1ScopedSet.html#a0f4bca41f7e821ca128c15033dc7c3c4", null ],
      [ "_var", "structzypp_1_1env_1_1ScopedSet.html#ad895020a4e78636a3b191b28e649ea16", null ],
      [ "_val", "structzypp_1_1env_1_1ScopedSet.html#ade744fcd8b2da59be7c70f779eedc3b7", null ]
    ] ],
    [ "zypp::LocaleGuard", "classzypp_1_1LocaleGuard.html", [
      [ "LocaleGuard", "classzypp_1_1LocaleGuard.html#a9cf5be9bbcf11384492777e3356362bb", null ],
      [ "~LocaleGuard", "classzypp_1_1LocaleGuard.html#ab3c443952fb2c1d6759de6bea3f71d14", null ],
      [ "NON_COPYABLE", "classzypp_1_1LocaleGuard.html#a887d5112c0ba4f0a127c8b84454e6ccb", null ],
      [ "NON_MOVABLE", "classzypp_1_1LocaleGuard.html#ab48b9166191df6ed9aad56ba9fced79a", null ],
      [ "restore", "classzypp_1_1LocaleGuard.html#aadbcede9ac0951cdb1b1df769cd522b4", null ],
      [ "_category", "classzypp_1_1LocaleGuard.html#a62b58e472e03ca42f8b92c43e0541272", null ],
      [ "_value", "classzypp_1_1LocaleGuard.html#ac42a660140f65e315c3a630ec112ca4c", null ]
    ] ],
    [ "ReleaseFileGuard", "classMediaSetAccess_1_1ReleaseFileGuard.html", null ],
    [ "zypp::PluginExecutor", "classzypp_1_1PluginExecutor.html", [
      [ "Impl", "classzypp_1_1PluginExecutor_1_1Impl.html", [
        [ "Impl", "classzypp_1_1PluginExecutor_1_1Impl.html#a8e2f55b0959edae7a5e9dc81b5bb0b1c", null ],
        [ "Impl", "classzypp_1_1PluginExecutor_1_1Impl.html#ac11a4ca4ee57aba255bc6b6c9d2d6aa4", null ],
        [ "Impl", "classzypp_1_1PluginExecutor_1_1Impl.html#a0ac75c960b6364015055a49c061e83d8", null ],
        [ "~Impl", "classzypp_1_1PluginExecutor_1_1Impl.html#a16cd45545ee8db550f440fbee24a7034", null ],
        [ "operator=", "classzypp_1_1PluginExecutor_1_1Impl.html#a7eacdf1145823784fc749bc05fee855b", null ],
        [ "operator=", "classzypp_1_1PluginExecutor_1_1Impl.html#a1d526f7c29dfe74d24e9601d4e3b596b", null ],
        [ "empty", "classzypp_1_1PluginExecutor_1_1Impl.html#a3d0473bf50dda8b38135fd383de74a21", null ],
        [ "size", "classzypp_1_1PluginExecutor_1_1Impl.html#abcdccdeca942f8f341d5670185788ec1", null ],
        [ "load", "classzypp_1_1PluginExecutor_1_1Impl.html#aff5765b0f2a05d92307a89fd8b54c210", null ],
        [ "send", "classzypp_1_1PluginExecutor_1_1Impl.html#aceaa0368253a9ee84e9a8cb71e2f367c", null ],
        [ "scripts", "classzypp_1_1PluginExecutor_1_1Impl.html#acd57b24ea8f5e92209eb8ef6710fedb6", null ],
        [ "doLoad", "classzypp_1_1PluginExecutor_1_1Impl.html#a54aea6f4ee23857f50eca0ea2a340615", null ],
        [ "doSend", "classzypp_1_1PluginExecutor_1_1Impl.html#a42a394a5ef0c10e0e8baea3fd7af3478", null ],
        [ "_scripts", "classzypp_1_1PluginExecutor_1_1Impl.html#a70f460128338a9040c0180e9767ee152", null ]
      ] ],
      [ "PluginExecutor", "classzypp_1_1PluginExecutor.html#aabe72219b4b991543b7d3cd289ea8795", null ],
      [ "~PluginExecutor", "classzypp_1_1PluginExecutor.html#ab81dffb0ac55a1865f656f4716a6bf6d", null ],
      [ "operator bool", "classzypp_1_1PluginExecutor.html#aa14a636e15b435177b31fb7519ee7ba5", null ],
      [ "empty", "classzypp_1_1PluginExecutor.html#ab96c5c6b1ceae6bff49de0304f7be28e", null ],
      [ "size", "classzypp_1_1PluginExecutor.html#a8acb9a436b51f10312ee44a386a42204", null ],
      [ "load", "classzypp_1_1PluginExecutor.html#a7e37b4a7bc1c2e7770d2f547efe01598", null ],
      [ "send", "classzypp_1_1PluginExecutor.html#ab337837061a8ef89198eafb92cac59b9", null ],
      [ "operator<<", "classzypp_1_1PluginExecutor.html#a51aa85356ae14874f43bb2cfe45d2330", null ],
      [ "operator==", "classzypp_1_1PluginExecutor.html#af17a4a601b9a2d2d42fc90bc7f30bece", null ],
      [ "operator<<", "classzypp_1_1PluginExecutor.html#a51aa85356ae14874f43bb2cfe45d2330", null ],
      [ "operator==", "classzypp_1_1PluginExecutor.html#af17a4a601b9a2d2d42fc90bc7f30bece", null ],
      [ "operator!=", "classzypp_1_1PluginExecutor.html#a4cd9e3097ea688cb74af874a87ae5023", null ],
      [ "_pimpl", "classzypp_1_1PluginExecutor.html#a00ed7d5c82cc25d820e287f3e559d409", null ]
    ] ],
    [ "zypp::ResPoolProxy::ScopedSaveState", "structzypp_1_1ResPoolProxy_1_1ScopedSaveState.html", [
      [ "Impl", "structzypp_1_1ResPoolProxy_1_1ScopedSaveState_1_1Impl.html", [
        [ "Impl", "structzypp_1_1ResPoolProxy_1_1ScopedSaveState_1_1Impl.html#af1589827911c4eb9ec2ab6e63a4405d4", null ],
        [ "Impl", "structzypp_1_1ResPoolProxy_1_1ScopedSaveState_1_1Impl.html#af102fd85d744e974846365c2a4efd2b6", null ],
        [ "saveState", "structzypp_1_1ResPoolProxy_1_1ScopedSaveState_1_1Impl.html#aa379431612d2ed8e9b5352be4435e7f3", null ],
        [ "restoreState", "structzypp_1_1ResPoolProxy_1_1ScopedSaveState_1_1Impl.html#aa73f44f1dd1fd3cca4dbed65801e6ce5", null ],
        [ "_pool", "structzypp_1_1ResPoolProxy_1_1ScopedSaveState_1_1Impl.html#a022ee292dc2a632d85478b54f87aca30", null ],
        [ "_kind", "structzypp_1_1ResPoolProxy_1_1ScopedSaveState_1_1Impl.html#a4e3314d515fed881a82ec8de9d67f842", null ]
      ] ],
      [ "ScopedSaveState", "structzypp_1_1ResPoolProxy_1_1ScopedSaveState.html#a1cac177bf307e60b37f358b121027572", null ],
      [ "ScopedSaveState", "structzypp_1_1ResPoolProxy_1_1ScopedSaveState.html#a30dff5a3d4a1248c84d17f847bf4c212", null ],
      [ "~ScopedSaveState", "structzypp_1_1ResPoolProxy_1_1ScopedSaveState.html#a1eddf84240e007de4c3f7030799d090e", null ],
      [ "NON_COPYABLE_BUT_MOVE", "structzypp_1_1ResPoolProxy_1_1ScopedSaveState.html#a123ffc822fac7427ca9ce06a3b9d8d2d", null ],
      [ "acceptState", "structzypp_1_1ResPoolProxy_1_1ScopedSaveState.html#a295aec1908ebd1410df514ad47b23c19", null ],
      [ "_pimpl", "structzypp_1_1ResPoolProxy_1_1ScopedSaveState.html#ac341571bc2f1efa8636d6f65cc1b5579", null ]
    ] ],
    [ "zypp::AutoFD", "structzypp_1_1AutoFD.html", [
      [ "AutoFD", "structzypp_1_1AutoFD.html#a3cb06f937ed94fcfd87c648bec3e73ea", null ]
    ] ],
    [ "zypp::AutoFILE", "structzypp_1_1AutoFILE.html", [
      [ "AutoFILE", "structzypp_1_1AutoFILE.html#aeefd9e381d614835e21f5874fe9a9a51", null ]
    ] ],
    [ "AutoFREE< Tp >", "classAutoFREE_3_01Tp_01_4.html", null ]
];

==> libzypp-docs-17.37.18-2-x86_64.pkg.tar.zst: usr/share/doc/libzypp/html/autodoc/html/group__g__RAII.js <==
var group__g__RAII =
[
    [ "zypp::DtorReset", "classzypp_1_1DtorReset.html", [
      [ "Impl", "structzypp_1_1DtorReset_1_1Impl.html", [
        [ "Impl", "structzypp_1_1DtorReset_1_1Impl.html#a4712f33294c3d5ed9b7e705704b6defd", null ],
        [ "~Impl", "structzypp_1_1DtorReset_1_1Impl.html#a8c49eadfb70407829676978c010023bf", null ],
        [ "_var", "structzypp_1_1DtorReset_1_1Impl.html#a04f625138e68e7933302c3db8f901083", null ],
        [ "_val", "structzypp_1_1DtorReset_1_1Impl.html#adf7c174da71cc9b154e444f215eef825", null ]
      ] ],
      [ "DtorReset", "classzypp_1_1DtorReset.html#aa43af29f4262ca1b5ea3531ee575f523", null ],
      [ "DtorReset", "classzypp_1_1DtorReset.html#a106c8b56f67255234b046f14c1f3f5a7", null ],
      [ "DtorReset", "classzypp_1_1DtorReset.html#a0a719ff20b63f83e975ef848b4741dca", null ],
      [ "_pimpl", "classzypp_1_1DtorReset.html#a11c072d16bc47aa7872c323e275d6fa5", null ]
    ] ],
    [ "zypp::str::SafeBuf", "structzypp_1_1str_1_1SafeBuf.html", [
      [ "SafeBuf", "structzypp_1_1str_1_1SafeBuf.html#a586dabf29ac7a72b5f951d8c9144dd61", null ],
      [ "~SafeBuf", "structzypp_1_1str_1_1SafeBuf.html#a72cdcac6091c826bdc14995bc9c90e9c", null ],
      [ "asString", "structzypp_1_1str_1_1SafeBuf.html#a4e5b21b6f2ea1fc368dae67c0f3fe164", null ],
      [ "_buf", "structzypp_1_1str_1_1SafeBuf.html#a320bba0ea756554acbec4891d1342e05", null ]
    ] ],
    [ "zypp::AutoFD", "structzypp_1_1AutoFD.html", [
      [ "AutoFD", "structzypp_1_1AutoFD.html#a3cb06f937ed94fcfd87c648bec3e73ea", null ]
    ] ],
    [ "zypp::AutoFILE", "structzypp_1_1AutoFILE.html", [
      [ "AutoFILE", "structzypp_1_1AutoFILE.html#aeefd9e381d614835e21f5874fe9a9a51", null ]
    ] ],
    [ "AutoFREE< Tp >", "classAutoFREE_3_01Tp_01_4.html", null ],
    [ "zypp::env::ScopedSet", "structzypp_1_1env_1_1ScopedSet.html", [
      [ "ScopedSet", "structzypp_1_1env_1_1ScopedSet.html#a02f4fc4e5a9e16cfc227d819c790ffa1", null ],
      [ "ScopedSet", "structzypp_1_1env_1_1ScopedSet.html#aca93ed9695126bf8ec93dbba4af449d3", null ],
      [ "ScopedSet", "structzypp_1_1env_1_1ScopedSet.html#a37f3becbcd499d8988501741a7a6964d", null ],
      [ "ScopedSet", "structzypp_1_1env_1_1ScopedSet.html#a2684ce98aea79484fa3f7b27a09e2ace", null ],
      [ "~ScopedSet", "structzypp_1_1env_1_1ScopedSet.html#ae08c521454ba1482a56f77c7433e1c99", null ],
      [ "operator=", "structzypp_1_1env_1_1ScopedSet.html#a0b47063a69f477bb0ca7200d19fc5b6c", null ],
      [ "operator=", "structzypp_1_1env_1_1ScopedSet.html#a87bdaac67eb7466a08e049964e00ad0e", null ],
      [ "setval", "structzypp_1_1env_1_1ScopedSet.html#a0f4bca41f7e821ca128c15033dc7c3c4", null ],
      [ "_var", "structzypp_1_1env_1_1ScopedSet.html#ad895020a4e78636a3b191b28e649ea16", null ],
      [ "_val", "structzypp_1_1env_1_1ScopedSet.html#ade744fcd8b2da59be7c70f779eedc3b7", null ]
    ] ]
];
